random

package module
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 24, 2019 License: MIT Imports: 2 Imported by: 3

README

random

This repository holds a package includes some functions relative to random.

Download / Install

The easiest way to install is to run go get -u github.com/catsworld/random. You can also manually git clone the repository to $GOPATH/src/catsworld/random.

Documentation

Overview

Package random includes some functions relative to random.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Int added in v1.1.0

func Int(x, y int) int

Int returns a random integer in [x..y], with the help of crypto/rand.

func String

func String(ss []string) string

String returns a random string from the string slice.

Types

This section is empty.

Jump to